@@ -40,7 +40,7 @@ connectmgr_get_protocol_info(ActionEvent *event)
 static bool
 connectmgr_get_current_connection_ids(ActionEvent *event)
 {
-    upnp_add_response(event, "ConnectionIDs", "");
+    upnp_add_response(event, "ConnectionIDs", "0");
     return event->status;
 }
 
@@ -58,20 +58,12 @@ connectmgr_get_current_connection_info(ActionEvent *event)
     return event->status;
 }
 
-/*
 ServiceVariable connectmgr_service_variables[] = {
-  { "SourceProtocolInfo"
-  { "SinkProtocolInfo"
-  { "CurrentConnectionIDs"
-  { "A_ARG_TYPE_ConnectionStatus"
-  { "A_ARG_TYPE_ConnectionManager"
-  { "A_ARG_TYPE_Direction"
-  { "A_ARG_TYPE_ProtocolInfo"
-  { "A_ARG_TYPE_ConnectionID"
-  { "A_ARG_TYPE_AVTransportID"
-  { "A_ARG_TYPE_RcsID"
+  { "SourceProtocolInfo", "http-get:*:*:*" },
+  { "SinkProtocolInfo", "" },
+  { "CurrentConnectionIDs", "0" },
+  { 0, }
 };
-*/
 
 ServiceAction connectmgr_service_actions[] = {
   { "GetProtocolInfo", connectmgr_get_protocol_info },
@@ -79,5 +71,5 @@ ServiceAction connectmgr_service_actions[] = {
 /*{ "ConnectionComplete", connectmgr_connection_complete },*/
   { "GetCurrentConnectionIDs", connectmgr_get_current_connection_ids },
   { "GetCurrentConnectionInfo", connectmgr_get_current_connection_info },
-  { NULL, NULL }
+  { 0, }
 };
