@@ -375,6 +375,8 @@ main(int argc, char **argv)
 	exit(EXIT_FAILURE);
     }
 
+    init_contentdir();
+
     init_upnp(listenip, listenport);
 
     while (true) {
@@ -404,6 +406,7 @@ main(int argc, char **argv)
     }
     
     finish_upnp();
+    finish_contentdir();
     finish_metadata();
 
     if (pidfilename != NULL)
