@@ -83,7 +83,6 @@ static const char *file_type_mime_types[] = {
     [FILE_UNKNOWN] 	= "application/octet-stream",
 };
 
-
 static const char *file_type_names[] = {
     [FILE_MP3] 		= "mp3",
     [FILE_MP3_ID3]	= "mp3", /* possibly id3mp3 or mp3id3 in the future */
@@ -115,6 +114,7 @@ static uint32_t entry_count = 0;
 static uint32_t entries_size = 0;
 static Entry **entries;
 char *file_types = DEFAULT_FILE_TYPES;
+static ithread_mutex_t metadata_mutex;
 #ifdef HAVE_ID3LIB
 bool id3_enabled = true;
 static ID3Tag *id3;
@@ -485,7 +485,7 @@ scan_entry(const char *fullpath, const char *name, int32_t parent)
         int c;
 
 	say(4, _("Scanning directory %s\n"), quote(fullpath));
-        dirent_count = scandir(fullpath, &dirents, NULL, NULL);
+        dirent_count = scandir(fullpath, &dirents, NULL, alphasort);
         if (dirent_count < 0) {
             warn(_("%s: cannot scan directory: %s\n"), quotearg(fullpath), errstr);
             return NULL;
@@ -581,9 +581,11 @@ scan_entry(const char *fullpath, const char *name, int32_t parent)
     return NULL;
 }
 
-bool
-init_metadata(char **pathv, int pathc)
+void
+init_metadata(void)
 {
+    ithread_mutex_init(&metadata_mutex, NULL);
+
     entries_size = DEFAULT_ENTRIES_SIZE;
     entries = xmalloc(sizeof(Entry *) * entries_size);
 
@@ -591,7 +593,11 @@ init_metadata(char **pathv, int pathc)
     if (id3_enabled)
 	id3 = ID3Tag_New();
 #endif
+}
 
+bool
+scan_entries(char **pathv, int pathc)
+{
     if (pathc > 1) {
 	int32_t *children;
 	EntryDetail *detail;
@@ -623,16 +629,12 @@ init_metadata(char **pathv, int pathc)
 	root_entry = scan_entry(pathv[0], ROOT_ENTRY_NAME, -1);
     }
 
-#ifdef HAVE_ID3LIB
-    if (id3_enabled)
-	ID3Tag_Delete(id3);
-#endif
 
     return root_entry != NULL;
 }
 
 void
-finish_metadata(void)
+clear_entries(void)
 {
     uint32_t c;
 
@@ -662,5 +664,31 @@ finish_metadata(void)
         free(entries[c]);
     }
 
+    entry_count = 0;
+}
+
+void
+finish_metadata(void)
+{
+    clear_entries();
+#ifdef HAVE_ID3LIB
+    if (id3_enabled)
+	ID3Tag_Delete(id3);
+#endif
     free(entries);
+    entries_size = 0;
+
+    ithread_mutex_destroy(&metadata_mutex);
+}
+
+void
+lock_metadata(void)
+{
+    ithread_mutex_lock(&metadata_mutex);
+}
+
+void
+unlock_metadata(void)
+{
+    ithread_mutex_unlock(&metadata_mutex);
 }
