@@ -1,4 +1,4 @@
-/* A Bison parser, made by GNU Bison 1.875d.  */
+/* A Bison parser, made by GNU Bison 2.0.  */
 
 /* Skeleton parser for Yacc-like parsing with Bison,
    Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.
@@ -108,6 +108,7 @@ yyerror(yyscan_t scanner, SearchCriteriaParseData *data, const char *error)
     data->error = error;
 }
 
+/* XXX: disabled %name-prefix="search_criteria_" */
 
 
 /* Enabling traces.  */
@@ -124,7 +125,7 @@ yyerror(yyscan_t scanner, SearchCriteriaParseData *data, const char *error)
 #endif
 
 #if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
-#line 44 "search-parser.y"
+#line 45 "search-parser.y"
 typedef union YYSTYPE {
     char *str;
     int token;
@@ -132,8 +133,8 @@ typedef union YYSTYPE {
     SearchCriteria *criteria;
     bool boolval;
 } YYSTYPE;
-/* Line 191 of yacc.c.  */
-#line 137 "search-parser.c"
+/* Line 190 of yacc.c.  */
+#line 138 "search-parser.c"
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 # define YYSTYPE_IS_TRIVIAL 1
@@ -144,8 +145,8 @@ typedef union YYSTYPE {
 /* Copy the second part of user declarations.  */
 
 
-/* Line 214 of yacc.c.  */
-#line 149 "search-parser.c"
+/* Line 213 of yacc.c.  */
+#line 150 "search-parser.c"
 
 #if ! defined (yyoverflow) || YYERROR_VERBOSE
 
@@ -160,14 +161,10 @@ typedef union YYSTYPE {
 
 # ifdef YYSTACK_USE_ALLOCA
 #  if YYSTACK_USE_ALLOCA
-#   define YYSTACK_ALLOC alloca
-#  endif
-# else
-#  if defined (alloca) || defined (_ALLOCA_H)
-#   define YYSTACK_ALLOC alloca
-#  else
 #   ifdef __GNUC__
 #    define YYSTACK_ALLOC __builtin_alloca
+#   else
+#    define YYSTACK_ALLOC alloca
 #   endif
 #  endif
 # endif
@@ -324,8 +321,8 @@ static const yysigned_char yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const unsigned char yyrline[] =
 {
-       0,    69,    69,    75,    83,    87,    94,   101,   108,   117,
-     118,   119,   120,   121,   122,   123,   124,   125,   128,   129
+       0,    70,    70,    76,    84,    88,    95,   102,   109,   118,
+     119,   120,   121,   122,   123,   124,   125,   126,   129,   130
 };
 #endif
 
@@ -480,20 +477,53 @@ do								\
     }								\
 while (0)
 
+
 #define YYTERROR	1
 #define YYERRCODE	256
 
-/* YYLLOC_DEFAULT -- Compute the default location (before the actions
-   are run).  */
 
+/* YYLLOC_DEFAULT -- Set CURRENT to span from RHS[1] to RHS[N].
+   If N is 0, then set CURRENT to the empty location which ends
+   the previous symbol: RHS[0] (always defined).  */
+
+#define YYRHSLOC(Rhs, K) ((Rhs)[K])
 #ifndef YYLLOC_DEFAULT
-# define YYLLOC_DEFAULT(Current, Rhs, N)		\
-   ((Current).first_line   = (Rhs)[1].first_line,	\
-    (Current).first_column = (Rhs)[1].first_column,	\
-    (Current).last_line    = (Rhs)[N].last_line,	\
-    (Current).last_column  = (Rhs)[N].last_column)
+# define YYLLOC_DEFAULT(Current, Rhs, N)				\
+    do									\
+      if (N)								\
+	{								\
+	  (Current).first_line   = YYRHSLOC (Rhs, 1).first_line;	\
+	  (Current).first_column = YYRHSLOC (Rhs, 1).first_column;	\
+	  (Current).last_line    = YYRHSLOC (Rhs, N).last_line;		\
+	  (Current).last_column  = YYRHSLOC (Rhs, N).last_column;	\
+	}								\
+      else								\
+	{								\
+	  (Current).first_line   = (Current).last_line   =		\
+	    YYRHSLOC (Rhs, 0).last_line;				\
+	  (Current).first_column = (Current).last_column =		\
+	    YYRHSLOC (Rhs, 0).last_column;				\
+	}								\
+    while (0)
 #endif
 
+
+/* YY_LOCATION_PRINT -- Print the location on the stream.
+   This macro was not mandated originally: define only if we know
+   we won't break user code: when these are the locations we know.  */
+
+#ifndef YY_LOCATION_PRINT
+# if YYLTYPE_IS_TRIVIAL
+#  define YY_LOCATION_PRINT(File, Loc)			\
+     fprintf (File, "%d.%d-%d.%d",			\
+              (Loc).first_line, (Loc).first_column,	\
+              (Loc).last_line,  (Loc).last_column)
+# else
+#  define YY_LOCATION_PRINT(File, Loc) ((void) 0)
+# endif
+#endif
+
+
 /* YYLEX -- calling `yylex' with the right arguments.  */
 
 #ifdef YYLEX_PARAM
@@ -516,19 +546,13 @@ do {						\
     YYFPRINTF Args;				\
 } while (0)
 
-# define YYDSYMPRINT(Args)			\
-do {						\
-  if (yydebug)					\
-    yysymprint Args;				\
-} while (0)
-
-# define YYDSYMPRINTF(Title, Token, Value, Location)		\
+# define YY_SYMBOL_PRINT(Title, Type, Value, Location)		\
 do {								\
   if (yydebug)							\
     {								\
       YYFPRINTF (stderr, "%s ", Title);				\
       yysymprint (stderr, 					\
-                  Token, Value);	\
+                  Type, Value);	\
       YYFPRINTF (stderr, "\n");					\
     }								\
 } while (0)
@@ -595,8 +619,7 @@ do {					\
 int yydebug;
 #else /* !YYDEBUG */
 # define YYDPRINTF(Args)
-# define YYDSYMPRINT(Args)
-# define YYDSYMPRINTF(Title, Token, Value, Location)
+# define YY_SYMBOL_PRINT(Title, Type, Value, Location)
 # define YY_STACK_PRINT(Bottom, Top)
 # define YY_REDUCE_PRINT(Rule)
 #endif /* !YYDEBUG */
@@ -614,10 +637,6 @@ int yydebug;
    SIZE_MAX < YYSTACK_BYTES (YYMAXDEPTH)
    evaluated with infinite-precision integer arithmetic.  */
 
-#if defined (YYMAXDEPTH) && YYMAXDEPTH == 0
-# undef YYMAXDEPTH
-#endif
-
 #ifndef YYMAXDEPTH
 # define YYMAXDEPTH 10000
 #endif
@@ -699,15 +718,15 @@ yysymprint (yyoutput, yytype, yyvaluep)
   (void) yyvaluep;
 
   if (yytype < YYNTOKENS)
-    {
-      YYFPRINTF (yyoutput, "token %s (", yytname[yytype]);
-# ifdef YYPRINT
-      YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
-# endif
-    }
+    YYFPRINTF (yyoutput, "token %s (", yytname[yytype]);
   else
     YYFPRINTF (yyoutput, "nterm %s (", yytname[yytype]);
 
+
+# ifdef YYPRINT
+  if (yytype < YYNTOKENS)
+    YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
+# endif
   switch (yytype)
     {
       default:
@@ -723,10 +742,11 @@ yysymprint (yyoutput, yytype, yyvaluep)
 
 #if defined (__STDC__) || defined (__cplusplus)
 static void
-yydestruct (int yytype, YYSTYPE *yyvaluep)
+yydestruct (const char *yymsg, int yytype, YYSTYPE *yyvaluep)
 #else
 static void
-yydestruct (yytype, yyvaluep)
+yydestruct (yymsg, yytype, yyvaluep)
+    const char *yymsg;
     int yytype;
     YYSTYPE *yyvaluep;
 #endif
@@ -734,27 +754,31 @@ yydestruct (yytype, yyvaluep)
   /* Pacify ``unused variable'' warnings.  */
   (void) yyvaluep;
 
+  if (!yymsg)
+    yymsg = "Deleting";
+  YY_SYMBOL_PRINT (yymsg, yytype, yyvaluep, yylocationp);
+
   switch (yytype)
     {
       case 6: /* T_STRING */
-#line 63 "search-parser.y"
-        { free(yyvaluep->str); };
-#line 743 "search-parser.c"
+#line 64 "search-parser.y"
+        { free((yyvaluep->str)); };
+#line 767 "search-parser.c"
         break;
       case 7: /* T_PROPERTY */
-#line 63 "search-parser.y"
-        { free(yyvaluep->str); };
-#line 748 "search-parser.c"
+#line 64 "search-parser.y"
+        { free((yyvaluep->str)); };
+#line 772 "search-parser.c"
         break;
       case 23: /* input */
-#line 65 "search-parser.y"
-        { free_search_criteria(yyvaluep->criteria); };
-#line 753 "search-parser.c"
+#line 66 "search-parser.y"
+        { free_search_criteria((yyvaluep->criteria)); };
+#line 777 "search-parser.c"
         break;
       case 24: /* search_expr */
-#line 64 "search-parser.y"
-        { free_search_expr(yyvaluep->expr); };
-#line 758 "search-parser.c"
+#line 65 "search-parser.y"
+        { free_search_expr((yyvaluep->expr)); };
+#line 782 "search-parser.c"
         break;
 
       default:
@@ -773,7 +797,7 @@ int yyparse ();
 # endif
 #else /* ! YYPARSE_PARAM */
 #if defined (__STDC__) || defined (__cplusplus)
-int yyparse ( yyscan_t scanner ,  SearchCriteriaParseData *data );
+int yyparse (yyscan_t scanner, SearchCriteriaParseData *data);
 #else
 int yyparse ();
 #endif
@@ -798,19 +822,19 @@ int yyparse (YYPARSE_PARAM)
 #else /* ! YYPARSE_PARAM */
 #if defined (__STDC__) || defined (__cplusplus)
 int
-yyparse ( yyscan_t scanner ,  SearchCriteriaParseData *data )
+yyparse (yyscan_t scanner, SearchCriteriaParseData *data)
 #else
 int
 yyparse (scanner, data)
-     yyscan_t scanner ;
-     SearchCriteriaParseData *data ;
+    yyscan_t scanner;
+    SearchCriteriaParseData *data;
 #endif
 #endif
 {
-  /* The lookahead symbol.  */
+  /* The look-ahead symbol.  */
 int yychar;
 
-/* The semantic value of the lookahead symbol.  */
+/* The semantic value of the look-ahead symbol.  */
 YYSTYPE yylval;
 
 /* Number of syntax errors so far.  */
@@ -821,7 +845,7 @@ int yynerrs;
   int yyresult;
   /* Number of tokens to shift before error messages enabled.  */
   int yyerrstatus;
-  /* Lookahead token as an internal (translated) token number.  */
+  /* Look-ahead token as an internal (translated) token number.  */
   int yytoken = 0;
 
   /* Three stacks and their tools:
@@ -873,6 +897,8 @@ int yynerrs;
   yyvsp = yyvs;
 
 
+  yyvsp[0] = yylval;
+
   goto yysetstate;
 
 /*------------------------------------------------------------.
@@ -962,18 +988,18 @@ int yynerrs;
 yybackup:
 
 /* Do appropriate processing given the current state.  */
-/* Read a lookahead token if we need one and don't already have one.  */
+/* Read a look-ahead token if we need one and don't already have one.  */
 /* yyresume: */
 
-  /* First try to decide what to do without reference to lookahead token.  */
+  /* First try to decide what to do without reference to look-ahead token.  */
 
   yyn = yypact[yystate];
   if (yyn == YYPACT_NINF)
     goto yydefault;
 
-  /* Not known => get a lookahead token if don't already have one.  */
+  /* Not known => get a look-ahead token if don't already have one.  */
 
-  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
+  /* YYCHAR is either YYEMPTY or YYEOF or a valid look-ahead symbol.  */
   if (yychar == YYEMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token: "));
@@ -988,7 +1014,7 @@ yybackup:
   else
     {
       yytoken = YYTRANSLATE (yychar);
-      YYDSYMPRINTF ("Next token is", yytoken, &yylval, &yylloc);
+      YY_SYMBOL_PRINT ("Next token is", yytoken, &yylval, &yylloc);
     }
 
   /* If the proper action on seeing token YYTOKEN is to reduce or to
@@ -1008,8 +1034,8 @@ yybackup:
   if (yyn == YYFINAL)
     YYACCEPT;
 
-  /* Shift the lookahead token.  */
-  YYDPRINTF ((stderr, "Shifting token %s, ", yytname[yytoken]));
+  /* Shift the look-ahead token.  */
+  YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);
 
   /* Discard the token being shifted unless it is eof.  */
   if (yychar != YYEOF)
@@ -1059,130 +1085,130 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 70 "search-parser.y"
+#line 71 "search-parser.y"
     {
-		    yyval.criteria = xmalloc(sizeof(SearchCriteria));
-		    yyval.criteria->expr = NULL;
-		    data->criteria = yyval.criteria;
+		    (yyval.criteria) = xmalloc(sizeof(SearchCriteria));
+		    (yyval.criteria)->expr = NULL;
+		    data->criteria = (yyval.criteria);
 		  }
     break;
 
   case 3:
-#line 76 "search-parser.y"
+#line 77 "search-parser.y"
     {
-		    yyval.criteria = xmalloc(sizeof(SearchCriteria));
-		    yyval.criteria->expr = yyvsp[0].expr;
-		    data->criteria = yyval.criteria;
+		    (yyval.criteria) = xmalloc(sizeof(SearchCriteria));
+		    (yyval.criteria)->expr = (yyvsp[0].expr);
+		    data->criteria = (yyval.criteria);
 		  }
     break;
 
   case 4:
-#line 84 "search-parser.y"
+#line 85 "search-parser.y"
     {
-		    yyval.expr = yyvsp[-1].expr;
+		    (yyval.expr) = (yyvsp[-1].expr);
 		  }
     break;
 
   case 5:
-#line 88 "search-parser.y"
+#line 89 "search-parser.y"
     {
-		    yyval.expr = xmalloc(sizeof(SearchExpr));
-		    yyval.expr->type = T_AND;
-		    yyval.expr->u.logical.expr1 = yyvsp[-2].expr;
-		    yyval.expr->u.logical.expr2 = yyvsp[0].expr;
+		    (yyval.expr) = xmalloc(sizeof(SearchExpr));
+		    (yyval.expr)->type = T_AND;
+		    (yyval.expr)->u.logical.expr1 = (yyvsp[-2].expr);
+		    (yyval.expr)->u.logical.expr2 = (yyvsp[0].expr);
 		  }
     break;
 
   case 6:
-#line 95 "search-parser.y"
+#line 96 "search-parser.y"
     {
-		    yyval.expr = xmalloc(sizeof(SearchExpr));
-		    yyval.expr->type = T_OR;
-		    yyval.expr->u.logical.expr1 = yyvsp[-2].expr;
-		    yyval.expr->u.logical.expr2 = yyvsp[0].expr;
+		    (yyval.expr) = xmalloc(sizeof(SearchExpr));
+		    (yyval.expr)->type = T_OR;
+		    (yyval.expr)->u.logical.expr1 = (yyvsp[-2].expr);
+		    (yyval.expr)->u.logical.expr2 = (yyvsp[0].expr);
 		  }
     break;
 
   case 7:
-#line 102 "search-parser.y"
+#line 103 "search-parser.y"
     {
-		    yyval.expr = xmalloc(sizeof(SearchExpr));
-		    yyval.expr->type = yyvsp[-1].token;
-		    yyval.expr->u.binary.property = yyvsp[-2].str;
-		    yyval.expr->u.binary.value = yyvsp[0].str;
+		    (yyval.expr) = xmalloc(sizeof(SearchExpr));
+		    (yyval.expr)->type = (yyvsp[-1].token);
+		    (yyval.expr)->u.binary.property = (yyvsp[-2].str);
+		    (yyval.expr)->u.binary.value = (yyvsp[0].str);
 		  }
     break;
 
   case 8:
-#line 109 "search-parser.y"
+#line 110 "search-parser.y"
     {
-		    yyval.expr = xmalloc(sizeof(SearchExpr));
-		    yyval.expr->type = T_EXISTS;
-		    yyval.expr->u.exists.property = yyvsp[-2].str;
-		    yyval.expr->u.exists.must_exist = yyvsp[0].boolval;
+		    (yyval.expr) = xmalloc(sizeof(SearchExpr));
+		    (yyval.expr)->type = T_EXISTS;
+		    (yyval.expr)->u.exists.property = (yyvsp[-2].str);
+		    (yyval.expr)->u.exists.must_exist = (yyvsp[0].boolval);
 		  }
     break;
 
   case 9:
-#line 117 "search-parser.y"
-    { yyval.token = T_EQ; }
+#line 118 "search-parser.y"
+    { (yyval.token) = T_EQ; }
     break;
 
   case 10:
-#line 118 "search-parser.y"
-    { yyval.token = T_NE; }
+#line 119 "search-parser.y"
+    { (yyval.token) = T_NE; }
     break;
 
   case 11:
-#line 119 "search-parser.y"
-    { yyval.token = T_LT; }
+#line 120 "search-parser.y"
+    { (yyval.token) = T_LT; }
     break;
 
   case 12:
-#line 120 "search-parser.y"
-    { yyval.token = T_LE; }
+#line 121 "search-parser.y"
+    { (yyval.token) = T_LE; }
     break;
 
   case 13:
-#line 121 "search-parser.y"
-    { yyval.token = T_GT; }
+#line 122 "search-parser.y"
+    { (yyval.token) = T_GT; }
     break;
 
   case 14:
-#line 122 "search-parser.y"
-    { yyval.token = T_GE; }
+#line 123 "search-parser.y"
+    { (yyval.token) = T_GE; }
     break;
 
   case 15:
-#line 123 "search-parser.y"
-    { yyval.token = T_CONTAINS; }
+#line 124 "search-parser.y"
+    { (yyval.token) = T_CONTAINS; }
     break;
 
   case 16:
-#line 124 "search-parser.y"
-    { yyval.token = T_DOES_NOT_CONTAIN; }
+#line 125 "search-parser.y"
+    { (yyval.token) = T_DOES_NOT_CONTAIN; }
     break;
 
   case 17:
-#line 125 "search-parser.y"
-    { yyval.token = T_DERIVED_FROM; }
+#line 126 "search-parser.y"
+    { (yyval.token) = T_DERIVED_FROM; }
     break;
 
   case 18:
-#line 128 "search-parser.y"
-    { yyval.boolval = false; }
+#line 129 "search-parser.y"
+    { (yyval.boolval) = false; }
     break;
 
   case 19:
-#line 129 "search-parser.y"
-    { yyval.boolval = true; }
+#line 130 "search-parser.y"
+    { (yyval.boolval) = true; }
     break;
 
 
     }
 
-/* Line 1010 of yacc.c.  */
-#line 1186 "search-parser.c"
+/* Line 1037 of yacc.c.  */
+#line 1212 "search-parser.c"
 
   yyvsp -= yylen;
   yyssp -= yylen;
@@ -1282,7 +1308,7 @@ yyerrlab:
 
   if (yyerrstatus == 3)
     {
-      /* If just tried and failed to reuse lookahead token after an
+      /* If just tried and failed to reuse look-ahead token after an
 	 error, discard it.  */
 
       if (yychar <= YYEOF)
@@ -1292,23 +1318,22 @@ yyerrlab:
 	  if (yychar == YYEOF)
 	     for (;;)
 	       {
+
 		 YYPOPSTACK;
 		 if (yyssp == yyss)
 		   YYABORT;
-		 YYDSYMPRINTF ("Error: popping", yystos[*yyssp], yyvsp, yylsp);
-		 yydestruct (yystos[*yyssp], yyvsp);
+		 yydestruct ("Error: popping",
+                             yystos[*yyssp], yyvsp);
 	       }
         }
       else
 	{
-	  YYDSYMPRINTF ("Error: discarding", yytoken, &yylval, &yylloc);
-	  yydestruct (yytoken, &yylval);
+	  yydestruct ("Error: discarding", yytoken, &yylval);
 	  yychar = YYEMPTY;
-
 	}
     }
 
-  /* Else will try to reuse lookahead token after shifting the error
+  /* Else will try to reuse look-ahead token after shifting the error
      token.  */
   goto yyerrlab1;
 
@@ -1325,7 +1350,7 @@ yyerrorlab:
      goto yyerrorlab;
 #endif
 
-  yyvsp -= yylen;
+yyvsp -= yylen;
   yyssp -= yylen;
   yystate = *yyssp;
   goto yyerrlab1;
@@ -1355,8 +1380,8 @@ yyerrlab1:
       if (yyssp == yyss)
 	YYABORT;
 
-      YYDSYMPRINTF ("Error: popping", yystos[*yyssp], yyvsp, yylsp);
-      yydestruct (yystos[yystate], yyvsp);
+
+      yydestruct ("Error: popping", yystos[yystate], yyvsp);
       YYPOPSTACK;
       yystate = *yyssp;
       YY_STACK_PRINT (yyss, yyssp);
@@ -1365,11 +1390,12 @@ yyerrlab1:
   if (yyn == YYFINAL)
     YYACCEPT;
 
-  YYDPRINTF ((stderr, "Shifting error token, "));
-
   *++yyvsp = yylval;
 
 
+  /* Shift the error token. */
+  YY_SYMBOL_PRINT ("Shifting", yystos[yyn], yyvsp, yylsp);
+
   yystate = yyn;
   goto yynewstate;
 
@@ -1385,6 +1411,9 @@ yyacceptlab:
 | yyabortlab -- YYABORT comes here.  |
 `-----------------------------------*/
 yyabortlab:
+  yydestruct ("Error: discarding lookahead",
+              yytoken, &yylval);
+  yychar = YYEMPTY;
   yyresult = 1;
   goto yyreturn;
 
@@ -1407,6 +1436,6 @@ yyreturn:
 }
 
 
-#line 132 "search-parser.y"
+#line 133 "search-parser.y"
 
 
